@@ -3,8 +3,11 @@ from copy import deepcopy
 from pathlib import Path
 
 import pytest
-from pyformatters_textranksummarizer.textranksummarizer import TextRankSummarizerFormatter, \
-    TextRankSummarizerParameters, TextRankAlgo
+from pyformatters_textranksummarizer.textranksummarizer import (
+    TextRankSummarizerFormatter,
+    TextRankSummarizerParameters,
+    TextRankAlgo,
+)
 from pymultirole_plugins.v1.schema import Document, DocumentList
 from starlette.responses import Response
 
@@ -13,7 +16,8 @@ from starlette.responses import Response
 def test_textranksummarizer_french(algorithm):
     parameters = TextRankSummarizerParameters(lang="fr", algo=algorithm)
     formatter = TextRankSummarizerFormatter()
-    doc = Document(text="""Un nuage de fumée juste après l’explosion, le 1er juin 2019.
+    doc = Document(
+        text="""Un nuage de fumée juste après l’explosion, le 1er juin 2019.
         Une déflagration dans une importante usine d’explosifs du centre de la Russie a fait au moins 79 blessés samedi 1er juin.
         L’explosion a eu lieu dans l’usine Kristall à Dzerzhinsk, une ville située à environ 400 kilomètres à l’est de Moscou, dans la région de Nijni-Novgorod.
         « Il y a eu une explosion technique dans l’un des ateliers, suivie d’un incendie qui s’est propagé sur une centaine de mètres carrés », a expliqué un porte-parole des services d’urgence.
@@ -23,25 +27,26 @@ def test_textranksummarizer_french(algorithm):
         « Nous parlons de blessures par shrapnel d’une gravité moyenne et modérée », a-t-elle précisé.
         Selon des représentants de Kristall, cinq personnes travaillaient dans la zone où s’est produite l’explosion. Elles ont pu être évacuées en sécurité.
         Les pompiers locaux ont rapporté n’avoir aucune information sur des personnes qui se trouveraient encore dans l’usine.
-        """)
+        """
+    )
     resp: Response = formatter.format(doc, parameters)
     assert resp.status_code == 200
     assert resp.media_type == "text/plain"
     summary = resp.body.decode(resp.charset)
 
-    parameters.as_metadata = "summary"
+    parameters.as_altText = "summary"
     docs = formatter.process([doc], parameters)
     summarized: Document = docs[0]
-    assert summary == summarized.metadata['summary']
+    assert summary == summarized.altTexts[0].text
 
-    parameters.as_metadata = None
+    parameters.as_altText = None
     docs = formatter.process([doc], parameters)
     summarized: Document = docs[0]
     assert summary == summarized.text
 
 
 def test_textranksummarizer_french_with_sents():
-    testdir = Path(__file__).parent / 'data'
+    testdir = Path(__file__).parent / "data"
     json_file = testdir / "french.json"
     with json_file.open("r") as fin:
         doc = json.load(fin)
@@ -56,22 +61,24 @@ def test_textranksummarizer_french_with_sents():
 def test_textranksummarizer_english():
     parameters = TextRankSummarizerParameters(num_sentences=2)
     formatter = TextRankSummarizerFormatter()
-    doc = Document(text="""The tower is 324 metres (1,063 ft) tall, about the same height as an 81-storey building, and the tallest structure in Paris.
+    doc = Document(
+        text="""The tower is 324 metres (1,063 ft) tall, about the same height as an 81-storey building, and the tallest structure in Paris.
     Its base is square, measuring 125 metres (410 ft) on each side. During its construction, the Eiffel Tower surpassed the Washington Monument to become the tallest man-made structure in the world, a title it held for 41 years until the Chrysler Building in New York City was finished in 1930.
     It was the first structure to reach a height of 300 metres. Due to the addition of a broadcasting aerial at the top of the tower in 1957, it is now taller than the Chrysler Building by 5.2 metres (17 ft).
     Excluding transmitters, the Eiffel Tower is the second tallest free-standing structure in France after the Millau Viaduct.
-        """)
+        """
+    )
     resp: Response = formatter.format(doc, parameters)
     assert resp.status_code == 200
     assert resp.media_type == "text/plain"
     summary = resp.body.decode(resp.charset)
 
-    parameters.as_metadata = "summary"
+    parameters.as_altText = "summary"
     docs = formatter.process([doc], parameters)
     summarized: Document = docs[0]
-    assert summary == summarized.metadata['summary']
+    assert summary == summarized.altTexts[0].text
 
-    parameters.as_metadata = None
+    parameters.as_altText = None
     docs = formatter.process([doc], parameters)
     summarized: Document = docs[0]
     assert summary == summarized.text
@@ -79,7 +86,7 @@ def test_textranksummarizer_english():
 
 @pytest.mark.skip(reason="Not a test")
 def test_textranksummarizer_kantar():
-    testdir = Path(__file__).parent / 'data'
+    testdir = Path(__file__).parent / "data"
     json_file = testdir / "futilecyclingtxt-documents.json"
     with json_file.open("r") as fin:
         docs = json.load(fin)
@@ -91,7 +98,7 @@ def test_textranksummarizer_kantar():
         resp: Response = formatter.format(doc, parameters)
         assert resp.status_code == 200
         summary = resp.body.decode(resp.charset)
-        doc.metadata['summary'] = summary
+        doc.metadata["summary"] = summary
         # rows.append({
         #     'Title': doc.title,
         #     'Content': doc.text,
@@ -107,7 +114,7 @@ def test_textranksummarizer_kantar():
 
 
 def test_textranksummarizer_boerhinger():
-    testdir = Path(__file__).parent / 'data'
+    testdir = Path(__file__).parent / "data"
     json_file = testdir / "stefantestmov22-document-33933676.txt.json"
     with json_file.open("r") as fin:
         doc = json.load(fin)
